        function getT(rr,cc){
       if(rr==2 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==2 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 29 <strong>control</strong><br>0,1,2,4,5,7,9,10,13,14,16,20,22,24,25,27,28,29,30,31,33,35,36,38,43,44,45,47,50';}
       if(rr==2 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 22 <br>3,6,8,11,12,15,17,18,19,21,23,26,32,34,37,39,40,41,42,46,48,49';}
       if(rr==9 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==9 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 29 <strong>control</strong><br>0,1,2,4,5,7,9,10,13,14,16,20,22,24,25,27,28,29,30,31,33,35,36,38,43,44,45,47,50';}
       if(rr==9 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 22 <br>3,6,8,11,12,15,17,18,19,21,23,26,32,34,37,39,40,41,42,46,48,49';}
       if(rr==10 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==10 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 29 <strong>control</strong><br>0,1,2,4,5,7,9,10,13,14,16,20,22,24,25,27,28,29,30,31,33,35,36,38,43,44,45,47,50';}
       if(rr==10 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 22 <br>3,6,8,11,12,15,17,18,19,21,23,26,32,34,37,39,40,41,42,46,48,49';}
       if(rr==11 && cc==0){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==11 && cc==1){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 29 <strong>control</strong><br>0,1,2,4,5,7,9,10,13,14,16,20,22,24,25,27,28,29,30,31,33,35,36,38,43,44,45,47,50';}
       if(rr==11 && cc==2){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 22 <br>3,6,8,11,12,15,17,18,19,21,23,26,32,34,37,39,40,41,42,46,48,49';}
       if(rr==12 && cc==0){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==12 && cc==1){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 29 <strong>control</strong><br>0,1,2,4,5,7,9,10,13,14,16,20,22,24,25,27,28,29,30,31,33,35,36,38,43,44,45,47,50';}
       if(rr==12 && cc==2){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 22 <br>3,6,8,11,12,15,17,18,19,21,23,26,32,34,37,39,40,41,42,46,48,49';}
       if(rr==13 && cc==0){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==13 && cc==1){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 29 <strong>control</strong><br>0,1,2,4,5,7,9,10,13,14,16,20,22,24,25,27,28,29,30,31,33,35,36,38,43,44,45,47,50';}
       if(rr==13 && cc==2){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 22 <br>3,6,8,11,12,15,17,18,19,21,23,26,32,34,37,39,40,41,42,46,48,49';}
       if(rr==14 && cc==0){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==14 && cc==1){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 29 <strong>control</strong><br>0,1,2,4,5,7,9,10,13,14,16,20,22,24,25,27,28,29,30,31,33,35,36,38,43,44,45,47,50';}
       if(rr==14 && cc==2){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 22 <br>3,6,8,11,12,15,17,18,19,21,23,26,32,34,37,39,40,41,42,46,48,49';}
       if(rr==15 && cc==0){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==15 && cc==1){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 29 <strong>control</strong><br>0,1,2,4,5,7,9,10,13,14,16,20,22,24,25,27,28,29,30,31,33,35,36,38,43,44,45,47,50';}
       if(rr==15 && cc==2){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 22 <br>3,6,8,11,12,15,17,18,19,21,23,26,32,34,37,39,40,41,42,46,48,49';}
       if(rr==16 && cc==0){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==16 && cc==1){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 29 <strong>control</strong><br>0,1,2,4,5,7,9,10,13,14,16,20,22,24,25,27,28,29,30,31,33,35,36,38,43,44,45,47,50';}
       if(rr==16 && cc==2){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 22 <br>3,6,8,11,12,15,17,18,19,21,23,26,32,34,37,39,40,41,42,46,48,49';}
}
