        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 29 <strong>control</strong><br>0,1,2,4,5,7,9,10,13,14,16,20,22,24,25,27,28,29,30,31,33,35,36,38,43,44,45,47,50';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 22 <br>3,6,8,11,12,15,17,18,19,21,23,26,32,34,37,39,40,41,42,46,48,49';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 29 <strong>control</strong><br>0,1,2,4,5,7,9,10,13,14,16,20,22,24,25,27,28,29,30,31,33,35,36,38,43,44,45,47,50';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 22 <br>3,6,8,11,12,15,17,18,19,21,23,26,32,34,37,39,40,41,42,46,48,49';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 29 <strong>control</strong><br>0,1,2,4,5,7,9,10,13,14,16,20,22,24,25,27,28,29,30,31,33,35,36,38,43,44,45,47,50';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 22 <br>3,6,8,11,12,15,17,18,19,21,23,26,32,34,37,39,40,41,42,46,48,49';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 29 <strong>control</strong><br>0,1,2,4,5,7,9,10,13,14,16,20,22,24,25,27,28,29,30,31,33,35,36,38,43,44,45,47,50';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 22 <br>3,6,8,11,12,15,17,18,19,21,23,26,32,34,37,39,40,41,42,46,48,49';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 29 <strong>control</strong><br>0,1,2,4,5,7,9,10,13,14,16,20,22,24,25,27,28,29,30,31,33,35,36,38,43,44,45,47,50';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 22 <br>3,6,8,11,12,15,17,18,19,21,23,26,32,34,37,39,40,41,42,46,48,49';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 29 <strong>control</strong><br>0,1,2,4,5,7,9,10,13,14,16,20,22,24,25,27,28,29,30,31,33,35,36,38,43,44,45,47,50';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 22 <br>3,6,8,11,12,15,17,18,19,21,23,26,32,34,37,39,40,41,42,46,48,49';}
}
