        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 29 <strong>control</strong><br>0,1,2,4,5,7,9,10,13,14,16,20,22,24,25,27,28,29,30,31,33,35,36,38,43,44,45,47,50';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 22 <br>3,6,8,11,12,15,17,18,19,21,23,26,32,34,37,39,40,41,42,46,48,49';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 29 <strong>control</strong><br>0,1,2,4,5,7,9,10,13,14,16,20,22,24,25,27,28,29,30,31,33,35,36,38,43,44,45,47,50';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 22 <br>3,6,8,11,12,15,17,18,19,21,23,26,32,34,37,39,40,41,42,46,48,49';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 29 <strong>control</strong><br>0,1,2,4,5,7,9,10,13,14,16,20,22,24,25,27,28,29,30,31,33,35,36,38,43,44,45,47,50';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 22 <br>3,6,8,11,12,15,17,18,19,21,23,26,32,34,37,39,40,41,42,46,48,49';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 29 <strong>control</strong><br>0,1,2,4,5,7,9,10,13,14,16,20,22,24,25,27,28,29,30,31,33,35,36,38,43,44,45,47,50';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 22 <br>3,6,8,11,12,15,17,18,19,21,23,26,32,34,37,39,40,41,42,46,48,49';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>33</strong> miembros: 29 <strong>control</strong><br>0,1,2,4,5,7,9,10,13,14,16,20,22,24,25,27,28,29,30,31,33,35,36,38,43,44,45,47,50';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260618 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 22 <br>3,6,8,11,12,15,17,18,19,21,23,26,32,34,37,39,40,41,42,46,48,49';}
}
